Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go

Issue 2575383002: Add server/cache support to gaeconfig. (Closed)
Patch Set: Un-collapse. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go
diff --git a/tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go b/tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go
index a7c1d7eb3e10107359c9189ae96c10cdf9b2664e..ded25033f7effd105220e30afd3049d37d74609c 100644
--- a/tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go
+++ b/tokenserver/appengine/certconfig/rpc_import_ca_configs_test.go
@@ -12,8 +12,8 @@ import (
ds "github.com/luci/gae/service/datastore"
"github.com/luci/gae/service/info"
"github.com/luci/luci-go/appengine/gaetesting"
- "github.com/luci/luci-go/common/config"
"github.com/luci/luci-go/common/config/impl/memory"
+ "github.com/luci/luci-go/luci_config/server/cfgclient/backend/testconfig"
"github.com/luci/luci-go/tokenserver/api/admin/v1"
@@ -251,10 +251,10 @@ PkoYH9WC8tSbqNof3g==
-----END CERTIFICATE-----
`
// prepareCfg injects config.Interface implementation with a bunch of
// config files.
func prepareCfg(c context.Context, configFile string) context.Context {
- return config.SetImplementation(c, memory.New(map[string]memory.ConfigSet{
+ return testconfig.WithCommonClient(c, memory.New(map[string]memory.ConfigSet{
"services/" + info.AppID(c): {
"tokenserver.cfg": configFile,
"certs/fake.ca.crt": fakeCACrt,
@@ -251,10 +251,10 @@ PkoYH9WC8tSbqNof3g==
`
-// prepareCfg injects config.Interface implementation with a bunch of
+// prepareCfg injects config.Backend implementation with a bunch of
// config files.
func prepareCfg(c context.Context, configFile string) context.Context {

Powered by Google App Engine
This is Rietveld 408576698